colcon-ros-bazel
=================

[![Travis CI](https://travis-ci.org/colcon/colcon-ros-bazel.svg?branch=master)](https://travis-ci.org/colcon/colcon-ros-bazel)
[![AppVeyor](https://ci.appveyor.com/api/projects/status/github/colcon/colcon-ros-bazel?svg=true&branch=master)](https://ci.appveyor.com/project/Theosakamg/colcon-ros-bazel)
[![codecov](https://codecov.io/gh/colcon/colcon-ros-bazel/branch/master/graph/badge.svg)](https://codecov.io/gh/colcon/colcon-ros-bazel)
[![PyPI version](https://img.shields.io/pypi/v/colcon_ros_bazel.svg)](https://pypi.python.org/pypi/colcon_ros_bazel/)


An extension for [colcon-core](https://github.com/colcon/colcon-core) to support ROS2 Bazel projects.

